@@ -781,6 +781,10 @@ use blib;use B::CC;my int $r;my $i:int=2;our double $d=3.0; $r=$i*$i; $r*=$d; pr
 >>>>
 12
 ######### 105 CC attrs ###############################
+my $s=q{ok};END{print $s}END{$x = 0}
+>>>>
+ok
+######### 106 CC 296/297 ###############################
 CCTESTS
 
         my $i = 100;
@@ -879,6 +883,12 @@ sub ctestok {
 sub ctest {
     my ($num, $expected, $backend, $base, $script, $todo) =  @_;
     my $name = $base."_$num";
+    my $b = $backend; # protect against parallel test name clashes
+    $b =~ s/-(D.*|f.*|v),//g;
+    $b =~ s/-/_/g;
+    $b =~ s/[, ]//g;
+    $b = lc($b);
+    $name .= $b;
     unlink($name, "$name.c", "$name.pl", "$name.exe");
     open F, ">", "$name.pl";
     print F $script;
@@ -888,7 +898,7 @@ sub ctest {
     # we don't want to change STDOUT/STDERR on STDOUT/STDERR tests, so no -qq
     my $nostdoutclobber = $base !~ /^ccode93i/;
     my $post = '';
-    my $b = ($] > 5.008 and $nostdoutclobber) ? "-qq,$backend" : "$backend";
+    $b = ($] > 5.008 and $nostdoutclobber) ? "-qq,$backend" : "$backend";
     ($b, $post) = split(" ", $b);
     $post = '' unless $post;
     $b .= q(,-fno-fold,-fno-warnings) if $] >= 5.013005 and $b !~ /-(O3|ffold|fwarnings)/;
@@ -1002,52 +1012,31 @@ sub todo_tests_default {
     my $ITHREADS  = ($Config{useithreads});
 
     my @todo  = ();
+    # no IO::Scalar
     push @todo, (15)  if $] < 5.007;
     # broken by fbb32b8bebe8ad C: revert *-,*+,*! fetch magic, assign all core GVs to their global symbols
-    # fixed by 1.42_70 82a4fb139f
-    # push @todo, (10)  if $ITHREADS;
     push @todo, (42..43) if $] < 5.012;
     if ($what =~ /^c(|_o[1-4])$/) {
-        #push @todo, (7)     if $] == 5.008005;
-        #push @todo, (21)    if $] >= 5.012 and $] < 5.014;
-        #push @todo, (15)    if $] > 5.010 and $] < 5.016 and $ITHREADS;
-        #push @todo, (27)    if $] >= 5.012 and $] < 5.014 and $ITHREADS and $DEBUGGING;
+        # a regression
+        push @todo, (12)  if $what eq 'c_o3' and !$ITHREADS and $] >= 5.008009 and $] < 5.010;
 
-	# @ISA issue 64
-        push @todo, (10,12,19,25,42,43,50)  if $what eq 'c_o4';
-        #push @todo, (48)  if $] >= 5.008009 and $] < 5.010 and $what eq 'c_o4';
-	# DynaLoader::dl_load_file()
-        #push @todo, (42..43) if $] > 5.015 and $what eq 'c_o4';
-        #push @todo, (15,42..45) if $] >= 5.016; #1.42_66
+        push @todo, (48)  if $what eq 'c_o4' and $ITHREADS;
+        push @todo, (8,18,19,25,26,28)  if $what eq 'c_o4' and !$ITHREADS;
     } elsif ($what =~ /^cc/) {
-	# 8,11,14..16,18..19 fail on 5.00505 + 5.6, old core failures (max 20)
-	# on cygwin 29 passes
-	#15,21,27,30,41-45,50,103,105
-        #15,46,50,103 fixed with 1.42_61
-	push @todo, (21,30,105);
+	push @todo, (21,30,105,106);
+	push @todo, (22,41,45,103) if $] < 5.007; #regressions
 	push @todo, (104,105) if $] < 5.007; # leaveloop, no cxstack
-	push @todo, (3,7,15,41,44,45) if $] > 5.008 and $] <= 5.008005;
         push @todo, (42,43) if $] > 5.008 and $] <= 5.008005 and !$ITHREADS;
 
-	push @todo, (33,45) if $] >= 5.010 and $] < 5.012;
-	push @todo, (14)    if $] >= 5.012;
+	#push @todo, (33,45) if $] >= 5.010 and $] < 5.012;
 	push @todo, (10,16,50) if $what eq 'cc_o2';
-	#push @todo, (29)    if $] >= 5.013 and $what eq 'cc_o2';
-	#push @todo, (43)     if $what eq 'cc_o2'; # -faelem
-	#push @todo, (103)   if $] > 5.007 and $] < 5.009 and $what eq 'cc_o1';
-	# only tested 5.8.4 and .5
-	push @todo, (27)    if $] <= 5.008005;
-	push @todo, (49)    if $] >= 5.007 and $] < 5.008008;
 	push @todo, (29)    if $] < 5.008008;
-	push @todo, (14)    if $] >= 5.010 and $^O !~ /MSWin32|cygwin/i;
+	push @todo, (22)    if $] < 5.010 and !$ITHREADS;
+	push @todo, (46)    if $] < 5.010;
 	# solaris also. I suspected nvx<=>cop_seq_*
 	push @todo, (12)    if $^O eq 'MSWin32' and $Config{cc} =~ /^cl/i;
 	push @todo, (26)    if $what =~ /^cc_o[12]/;
 	push @todo, (27)    if $] > 5.008008 and $] < 5.009 and $what eq 'cc_o2';
-	#push @todo, (25)    if $] >= 5.011004 and $DEBUGGING and $ITHREADS;
-	#push @todo, (3,4)   if $] >= 5.011004 and $] < 5.016 and $ITHREADS;
-	#push @todo, (49)    if $] >= 5.013009 and !$ITHREADS;
-        #push @todo, (15,42..45,103) if $] >= 5.016;
         push @todo, (103)   if ($] >= 5.012 and $] < 5.014 and !$ITHREADS);
         push @todo, (12)    if $] >= 5.019;
     }
